sched

package module
v1.8.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 15, 2025 License: Apache-2.0 Imports: 7 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Cron

func Cron(ctx context.Context, args ...object.Object) object.Object

Cron schedules a function to run at a specific time using a cron like expression.

The first argument is the cron expression. The second argument is the function to be scheduled.

func Every

func Every(ctx context.Context, args ...object.Object) object.Object

Every schedules a function to run every n seconds.

The first argument is the interval in seconds (float). The second argument is the function to be scheduled.

func Module

func Module() *object.Module

Module returns the sched module.

func Once

func Once(ctx context.Context, args ...object.Object) object.Object

Once schedules a function to run once.

The first argument is the interval in seconds (float). The second argument is the function to be scheduled.

Types

This section is empty.

Jump to